@@ -35,7 +35,13 @@
 #include "rclcpp_lifecycle/node_interfaces/lifecycle_node_interface.hpp"
 
 // Values to send over command interface to trigger error in write and read methods
-static constexpr unsigned int TRIGGER_READ_WRITE_ERROR_CALLS = 10000;
+
+namespace
+{
+const auto TIME = rclcpp::Time(0);
+const auto PERIOD = rclcpp::Duration::from_seconds(0.01);
+constexpr unsigned int TRIGGER_READ_WRITE_ERROR_CALLS = 10000;
+}  // namespace
 
 using namespace ::testing;  // NOLINT
 
@@ -45,7 +51,7 @@ using CallbackReturn = rclcpp_lifecycle::node_interfaces::LifecycleNodeInterface
 
 class DummyActuator : public hardware_interface::ActuatorInterface
 {
-  CallbackReturn on_init(const hardware_interface::HardwareInfo & /* info */) override
+  CallbackReturn on_init(const hardware_interface::HardwareInfo & /*info*/) override
   {
     // We hardcode the info
     return CallbackReturn::SUCCESS;
@@ -91,7 +97,8 @@ class DummyActuator : public hardware_interface::ActuatorInterface
 
   std::string get_name() const override { return "DummyActuator"; }
 
-  hardware_interface::return_type read() override
+  hardware_interface::return_type read(
+    const rclcpp::Time & /*time*/, const rclcpp::Duration & /*period*/) override
   {
     ++read_calls_;
     if (read_calls_ == TRIGGER_READ_WRITE_ERROR_CALLS)
@@ -103,7 +110,8 @@ class DummyActuator : public hardware_interface::ActuatorInterface
     return hardware_interface::return_type::OK;
   }
 
-  hardware_interface::return_type write() override
+  hardware_interface::return_type write(
+    const rclcpp::Time & /*time*/, const rclcpp::Duration & /*period*/) override
   {
     ++write_calls_;
     if (write_calls_ == TRIGGER_READ_WRITE_ERROR_CALLS)
@@ -150,7 +158,7 @@ private:
 
 class DummySensor : public hardware_interface::SensorInterface
 {
-  CallbackReturn on_init(const hardware_interface::HardwareInfo & /* info */) override
+  CallbackReturn on_init(const hardware_interface::HardwareInfo & /*info*/) override
   {
     // We hardcode the info
     return CallbackReturn::SUCCESS;
@@ -175,7 +183,8 @@ class DummySensor : public hardware_interface::SensorInterface
 
   std::string get_name() const override { return "DummySensor"; }
 
-  hardware_interface::return_type read() override
+  hardware_interface::return_type read(
+    const rclcpp::Time & /*time*/, const rclcpp::Duration & /*period*/) override
   {
     ++read_calls_;
     if (read_calls_ == TRIGGER_READ_WRITE_ERROR_CALLS)
@@ -277,7 +286,8 @@ class DummySystem : public hardware_interface::SystemInterface
 
   std::string get_name() const override { return "DummySystem"; }
 
-  hardware_interface::return_type read() override
+  hardware_interface::return_type read(
+    const rclcpp::Time & /*time*/, const rclcpp::Duration & /*period*/) override
   {
     ++read_calls_;
     if (read_calls_ == TRIGGER_READ_WRITE_ERROR_CALLS)
@@ -289,7 +299,8 @@ class DummySystem : public hardware_interface::SystemInterface
     return hardware_interface::return_type::OK;
   }
 
-  hardware_interface::return_type write() override
+  hardware_interface::return_type write(
+    const rclcpp::Time & /*time*/, const rclcpp::Duration & /*period*/) override
   {
     ++write_calls_;
     if (write_calls_ == TRIGGER_READ_WRITE_ERROR_CALLS)
@@ -361,9 +372,17 @@ class DummySystemPreparePerform : public hardware_interface::SystemInterface
 
   std::string get_name() const override { return "DummySystemPreparePerform"; }
 
-  hardware_interface::return_type read() override { return hardware_interface::return_type::OK; }
+  hardware_interface::return_type read(
+    const rclcpp::Time & /*time*/, const rclcpp::Duration & /*period*/) override
+  {
+    return hardware_interface::return_type::OK;
+  }
 
-  hardware_interface::return_type write() override { return hardware_interface::return_type::OK; }
+  hardware_interface::return_type write(
+    const rclcpp::Time & /*time*/, const rclcpp::Duration & /*period*/) override
+  {
+    return hardware_interface::return_type::OK;
+  }
 
   // Custom prepare/perform functions
   hardware_interface::return_type prepare_command_mode_switch(
@@ -412,29 +431,32 @@ TEST(TestComponentInterfaces, dummy_actuator)
 
   auto state_interfaces = actuator_hw.export_state_interfaces();
   ASSERT_EQ(2u, state_interfaces.size());
-  EXPECT_EQ("joint1", state_interfaces[0].get_name());
+  EXPECT_EQ("joint1/position", state_interfaces[0].get_name());
   EXPECT_EQ(hardware_interface::HW_IF_POSITION, state_interfaces[0].get_interface_name());
-  EXPECT_EQ("joint1", state_interfaces[1].get_name());
+  EXPECT_EQ("joint1", state_interfaces[0].get_prefix_name());
+  EXPECT_EQ("joint1/velocity", state_interfaces[1].get_name());
   EXPECT_EQ(hardware_interface::HW_IF_VELOCITY, state_interfaces[1].get_interface_name());
+  EXPECT_EQ("joint1", state_interfaces[1].get_prefix_name());
 
   auto command_interfaces = actuator_hw.export_command_interfaces();
   ASSERT_EQ(1u, command_interfaces.size());
-  EXPECT_EQ("joint1", command_interfaces[0].get_name());
+  EXPECT_EQ("joint1/velocity", command_interfaces[0].get_name());
   EXPECT_EQ(hardware_interface::HW_IF_VELOCITY, command_interfaces[0].get_interface_name());
+  EXPECT_EQ("joint1", command_interfaces[0].get_prefix_name());
 
   double velocity_value = 1.0;
   command_interfaces[0].set_value(velocity_value);  // velocity
-  ASSERT_EQ(hardware_interface::return_type::ERROR, actuator_hw.write());
+  ASSERT_EQ(hardware_interface::return_type::ERROR, actuator_hw.write(TIME, PERIOD));
 
   // Noting should change because it is UNCONFIGURED
   for (auto step = 0u; step < 10; ++step)
   {
-    ASSERT_EQ(hardware_interface::return_type::ERROR, actuator_hw.read());
+    ASSERT_EQ(hardware_interface::return_type::ERROR, actuator_hw.read(TIME, PERIOD));
 
     ASSERT_TRUE(std::isnan(state_interfaces[0].get_value()));  // position value
     ASSERT_TRUE(std::isnan(state_interfaces[1].get_value()));  // velocity
 
-    ASSERT_EQ(hardware_interface::return_type::ERROR, actuator_hw.write());
+    ASSERT_EQ(hardware_interface::return_type::ERROR, actuator_hw.write(TIME, PERIOD));
   }
 
   state = actuator_hw.configure();
@@ -444,12 +466,12 @@ TEST(TestComponentInterfaces, dummy_actuator)
   // Read and Write are working because it is INACTIVE
   for (auto step = 0u; step < 10; ++step)
   {
-    ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.read());
+    ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.read(TIME, PERIOD));
 
     EXPECT_EQ(step * velocity_value, state_interfaces[0].get_value());      // position value
     EXPECT_EQ(step ? velocity_value : 0, state_interfaces[1].get_value());  // velocity
 
-    ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.write());
+    ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.write(TIME, PERIOD));
   }
 
   state = actuator_hw.activate();
@@ -459,12 +481,12 @@ TEST(TestComponentInterfaces, dummy_actuator)
   // Read and Write are working because it is ACTIVE
   for (auto step = 0u; step < 10; ++step)
   {
-    ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.read());
+    ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.read(TIME, PERIOD));
 
     EXPECT_EQ((10 + step) * velocity_value, state_interfaces[0].get_value());  // position value
     EXPECT_EQ(velocity_value, state_interfaces[1].get_value());                // velocity
 
-    ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.write());
+    ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.write(TIME, PERIOD));
   }
 
   state = actuator_hw.shutdown();
@@ -474,12 +496,12 @@ TEST(TestComponentInterfaces, dummy_actuator)
   // Noting should change because it is FINALIZED
   for (auto step = 0u; step < 10; ++step)
   {
-    ASSERT_EQ(hardware_interface::return_type::ERROR, actuator_hw.read());
+    ASSERT_EQ(hardware_interface::return_type::ERROR, actuator_hw.read(TIME, PERIOD));
 
     EXPECT_EQ(20 * velocity_value, state_interfaces[0].get_value());  // position value
     EXPECT_EQ(0, state_interfaces[1].get_value());                    // velocity
 
-    ASSERT_EQ(hardware_interface::return_type::ERROR, actuator_hw.write());
+    ASSERT_EQ(hardware_interface::return_type::ERROR, actuator_hw.write(TIME, PERIOD));
   }
 
   EXPECT_EQ(
@@ -499,12 +521,13 @@ TEST(TestComponentInterfaces, dummy_sensor)
 
   auto state_interfaces = sensor_hw.export_state_interfaces();
   ASSERT_EQ(1u, state_interfaces.size());
-  EXPECT_EQ("joint1", state_interfaces[0].get_name());
+  EXPECT_EQ("joint1/voltage", state_interfaces[0].get_name());
   EXPECT_EQ("voltage", state_interfaces[0].get_interface_name());
+  EXPECT_EQ("joint1", state_interfaces[0].get_prefix_name());
   EXPECT_TRUE(std::isnan(state_interfaces[0].get_value()));
 
   // Not updated because is is UNCONFIGURED
-  sensor_hw.read();
+  sensor_hw.read(TIME, PERIOD);
   EXPECT_TRUE(std::isnan(state_interfaces[0].get_value()));
 
   // Updated because is is INACTIVE
@@ -514,7 +537,7 @@ TEST(TestComponentInterfaces, dummy_sensor)
   EXPECT_EQ(0.0, state_interfaces[0].get_value());
 
   // It can read now
-  sensor_hw.read();
+  sensor_hw.read(TIME, PERIOD);
   EXPECT_EQ(0x666, state_interfaces[0].get_value());
 }
 
@@ -529,38 +552,47 @@ TEST(TestComponentInterfaces, dummy_system)
 
   auto state_interfaces = system_hw.export_state_interfaces();
   ASSERT_EQ(6u, state_interfaces.size());
-  EXPECT_EQ("joint1", state_interfaces[0].get_name());
+  EXPECT_EQ("joint1/position", state_interfaces[0].get_name());
   EXPECT_EQ(hardware_interface::HW_IF_POSITION, state_interfaces[0].get_interface_name());
-  EXPECT_EQ("joint1", state_interfaces[1].get_name());
+  EXPECT_EQ("joint1", state_interfaces[0].get_prefix_name());
+  EXPECT_EQ("joint1/velocity", state_interfaces[1].get_name());
   EXPECT_EQ(hardware_interface::HW_IF_VELOCITY, state_interfaces[1].get_interface_name());
-  EXPECT_EQ("joint2", state_interfaces[2].get_name());
+  EXPECT_EQ("joint1", state_interfaces[1].get_prefix_name());
+  EXPECT_EQ("joint2/position", state_interfaces[2].get_name());
   EXPECT_EQ(hardware_interface::HW_IF_POSITION, state_interfaces[2].get_interface_name());
-  EXPECT_EQ("joint2", state_interfaces[3].get_name());
+  EXPECT_EQ("joint2", state_interfaces[2].get_prefix_name());
+  EXPECT_EQ("joint2/velocity", state_interfaces[3].get_name());
   EXPECT_EQ(hardware_interface::HW_IF_VELOCITY, state_interfaces[3].get_interface_name());
-  EXPECT_EQ("joint3", state_interfaces[4].get_name());
+  EXPECT_EQ("joint2", state_interfaces[3].get_prefix_name());
+  EXPECT_EQ("joint3/position", state_interfaces[4].get_name());
   EXPECT_EQ(hardware_interface::HW_IF_POSITION, state_interfaces[4].get_interface_name());
-  EXPECT_EQ("joint3", state_interfaces[5].get_name());
+  EXPECT_EQ("joint3", state_interfaces[4].get_prefix_name());
+  EXPECT_EQ("joint3/velocity", state_interfaces[5].get_name());
   EXPECT_EQ(hardware_interface::HW_IF_VELOCITY, state_interfaces[5].get_interface_name());
+  EXPECT_EQ("joint3", state_interfaces[5].get_prefix_name());
 
   auto command_interfaces = system_hw.export_command_interfaces();
   ASSERT_EQ(3u, command_interfaces.size());
-  EXPECT_EQ("joint1", command_interfaces[0].get_name());
+  EXPECT_EQ("joint1/velocity", command_interfaces[0].get_name());
   EXPECT_EQ(hardware_interface::HW_IF_VELOCITY, command_interfaces[0].get_interface_name());
-  EXPECT_EQ("joint2", command_interfaces[1].get_name());
+  EXPECT_EQ("joint1", command_interfaces[0].get_prefix_name());
+  EXPECT_EQ("joint2/velocity", command_interfaces[1].get_name());
   EXPECT_EQ(hardware_interface::HW_IF_VELOCITY, command_interfaces[1].get_interface_name());
-  EXPECT_EQ("joint3", command_interfaces[2].get_name());
+  EXPECT_EQ("joint2", command_interfaces[1].get_prefix_name());
+  EXPECT_EQ("joint3/velocity", command_interfaces[2].get_name());
   EXPECT_EQ(hardware_interface::HW_IF_VELOCITY, command_interfaces[2].get_interface_name());
+  EXPECT_EQ("joint3", command_interfaces[2].get_prefix_name());
 
   double velocity_value = 1.0;
   command_interfaces[0].set_value(velocity_value);  // velocity
   command_interfaces[1].set_value(velocity_value);  // velocity
   command_interfaces[2].set_value(velocity_value);  // velocity
-  ASSERT_EQ(hardware_interface::return_type::ERROR, system_hw.write());
+  ASSERT_EQ(hardware_interface::return_type::ERROR, system_hw.write(TIME, PERIOD));
 
   // Noting should change because it is UNCONFIGURED
   for (auto step = 0u; step < 10; ++step)
   {
-    ASSERT_EQ(hardware_interface::return_type::ERROR, system_hw.read());
+    ASSERT_EQ(hardware_interface::return_type::ERROR, system_hw.read(TIME, PERIOD));
 
     ASSERT_TRUE(std::isnan(state_interfaces[0].get_value()));  // position value
     ASSERT_TRUE(std::isnan(state_interfaces[1].get_value()));  // velocity
@@ -569,7 +601,7 @@ TEST(TestComponentInterfaces, dummy_system)
     ASSERT_TRUE(std::isnan(state_interfaces[4].get_value()));  // position value
     ASSERT_TRUE(std::isnan(state_interfaces[5].get_value()));  // velocity
 
-    ASSERT_EQ(hardware_interface::return_type::ERROR, system_hw.write());
+    ASSERT_EQ(hardware_interface::return_type::ERROR, system_hw.write(TIME, PERIOD));
   }
 
   state = system_hw.configure();
@@ -579,7 +611,7 @@ TEST(TestComponentInterfaces, dummy_system)
   // Read and Write are working because it is INACTIVE
   for (auto step = 0u; step < 10; ++step)
   {
-    ASSERT_EQ(hardware_interface::return_type::OK, system_hw.read());
+    ASSERT_EQ(hardware_interface::return_type::OK, system_hw.read(TIME, PERIOD));
 
     EXPECT_EQ(step * velocity_value, state_interfaces[0].get_value());      // position value
     EXPECT_EQ(step ? velocity_value : 0, state_interfaces[1].get_value());  // velocity
@@ -588,7 +620,7 @@ TEST(TestComponentInterfaces, dummy_system)
     EXPECT_EQ(step * velocity_value, state_interfaces[4].get_value());      // position value
     EXPECT_EQ(step ? velocity_value : 0, state_interfaces[5].get_value());  // velocity
 
-    ASSERT_EQ(hardware_interface::return_type::OK, system_hw.write());
+    ASSERT_EQ(hardware_interface::return_type::OK, system_hw.write(TIME, PERIOD));
   }
 
   state = system_hw.activate();
@@ -598,7 +630,7 @@ TEST(TestComponentInterfaces, dummy_system)
   // Read and Write are working because it is ACTIVE
   for (auto step = 0u; step < 10; ++step)
   {
-    ASSERT_EQ(hardware_interface::return_type::OK, system_hw.read());
+    ASSERT_EQ(hardware_interface::return_type::OK, system_hw.read(TIME, PERIOD));
 
     EXPECT_EQ((10 + step) * velocity_value, state_interfaces[0].get_value());  // position value
     EXPECT_EQ(velocity_value, state_interfaces[1].get_value());                // velocity
@@ -607,7 +639,7 @@ TEST(TestComponentInterfaces, dummy_system)
     EXPECT_EQ((10 + step) * velocity_value, state_interfaces[4].get_value());  // position value
     EXPECT_EQ(velocity_value, state_interfaces[5].get_value());                // velocity
 
-    ASSERT_EQ(hardware_interface::return_type::OK, system_hw.write());
+    ASSERT_EQ(hardware_interface::return_type::OK, system_hw.write(TIME, PERIOD));
   }
 
   state = system_hw.shutdown();
@@ -617,7 +649,7 @@ TEST(TestComponentInterfaces, dummy_system)
   // Noting should change because it is FINALIZED
   for (auto step = 0u; step < 10; ++step)
   {
-    ASSERT_EQ(hardware_interface::return_type::ERROR, system_hw.read());
+    ASSERT_EQ(hardware_interface::return_type::ERROR, system_hw.read(TIME, PERIOD));
 
     EXPECT_EQ(20 * velocity_value, state_interfaces[0].get_value());  // position value
     EXPECT_EQ(0.0, state_interfaces[1].get_value());                  // velocity
@@ -626,7 +658,7 @@ TEST(TestComponentInterfaces, dummy_system)
     EXPECT_EQ(20 * velocity_value, state_interfaces[4].get_value());  // position value
     EXPECT_EQ(0.0, state_interfaces[5].get_value());                  // velocity
 
-    ASSERT_EQ(hardware_interface::return_type::ERROR, system_hw.write());
+    ASSERT_EQ(hardware_interface::return_type::ERROR, system_hw.write(TIME, PERIOD));
   }
 
   EXPECT_EQ(hardware_interface::return_type::OK, system_hw.prepare_command_mode_switch({}, {}));
@@ -680,15 +712,15 @@ TEST(TestComponentInterfaces, dummy_actuator_read_error_behavior)
   EXPECT_EQ(lifecycle_msgs::msg::State::PRIMARY_STATE_ACTIVE, state.id());
   EXPECT_EQ(hardware_interface::lifecycle_state_names::ACTIVE, state.label());
 
-  ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.read());
-  ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.write());
+  ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.read(TIME, PERIOD));
+  ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.write(TIME, PERIOD));
 
   // Initiate error on write (this is first time therefore recoverable)
   for (auto i = 2ul; i < TRIGGER_READ_WRITE_ERROR_CALLS; ++i)
   {
-    ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.read());
+    ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.read(TIME, PERIOD));
   }
-  ASSERT_EQ(hardware_interface::return_type::ERROR, actuator_hw.read());
+  ASSERT_EQ(hardware_interface::return_type::ERROR, actuator_hw.read(TIME, PERIOD));
 
   state = actuator_hw.get_state();
   EXPECT_EQ(lifecycle_msgs::msg::State::PRIMARY_STATE_UNCONFIGURED, state.id());
@@ -703,15 +735,15 @@ TEST(TestComponentInterfaces, dummy_actuator_read_error_behavior)
   EXPECT_EQ(lifecycle_msgs::msg::State::PRIMARY_STATE_ACTIVE, state.id());
   EXPECT_EQ(hardware_interface::lifecycle_state_names::ACTIVE, state.label());
 
-  ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.read());
-  ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.write());
+  ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.read(TIME, PERIOD));
+  ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.write(TIME, PERIOD));
 
   // Initiate error on write (this is the second time therefore unrecoverable)
   for (auto i = 2ul; i < TRIGGER_READ_WRITE_ERROR_CALLS; ++i)
   {
-    ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.read());
+    ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.read(TIME, PERIOD));
   }
-  ASSERT_EQ(hardware_interface::return_type::ERROR, actuator_hw.read());
+  ASSERT_EQ(hardware_interface::return_type::ERROR, actuator_hw.read(TIME, PERIOD));
 
   state = actuator_hw.get_state();
   EXPECT_EQ(lifecycle_msgs::msg::State::PRIMARY_STATE_FINALIZED, state.id());
@@ -739,15 +771,15 @@ TEST(TestComponentInterfaces, dummy_actuator_write_error_behavior)
   EXPECT_EQ(lifecycle_msgs::msg::State::PRIMARY_STATE_ACTIVE, state.id());
   EXPECT_EQ(hardware_interface::lifecycle_state_names::ACTIVE, state.label());
 
-  ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.read());
-  ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.write());
+  ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.read(TIME, PERIOD));
+  ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.write(TIME, PERIOD));
 
   // Initiate error on write (this is first time therefore recoverable)
   for (auto i = 2ul; i < TRIGGER_READ_WRITE_ERROR_CALLS; ++i)
   {
-    ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.write());
+    ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.write(TIME, PERIOD));
   }
-  ASSERT_EQ(hardware_interface::return_type::ERROR, actuator_hw.write());
+  ASSERT_EQ(hardware_interface::return_type::ERROR, actuator_hw.write(TIME, PERIOD));
 
   state = actuator_hw.get_state();
   EXPECT_EQ(lifecycle_msgs::msg::State::PRIMARY_STATE_UNCONFIGURED, state.id());
@@ -762,15 +794,15 @@ TEST(TestComponentInterfaces, dummy_actuator_write_error_behavior)
   EXPECT_EQ(lifecycle_msgs::msg::State::PRIMARY_STATE_ACTIVE, state.id());
   EXPECT_EQ(hardware_interface::lifecycle_state_names::ACTIVE, state.label());
 
-  ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.read());
-  ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.write());
+  ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.read(TIME, PERIOD));
+  ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.write(TIME, PERIOD));
 
   // Initiate error on write (this is the second time therefore unrecoverable)
   for (auto i = 2ul; i < TRIGGER_READ_WRITE_ERROR_CALLS; ++i)
   {
-    ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.write());
+    ASSERT_EQ(hardware_interface::return_type::OK, actuator_hw.write(TIME, PERIOD));
   }
-  ASSERT_EQ(hardware_interface::return_type::ERROR, actuator_hw.write());
+  ASSERT_EQ(hardware_interface::return_type::ERROR, actuator_hw.write(TIME, PERIOD));
 
   state = actuator_hw.get_state();
   EXPECT_EQ(lifecycle_msgs::msg::State::PRIMARY_STATE_FINALIZED, state.id());
@@ -796,14 +828,14 @@ TEST(TestComponentInterfaces, dummy_sensor_read_error_behavior)
   EXPECT_EQ(lifecycle_msgs::msg::State::PRIMARY_STATE_ACTIVE, state.id());
   EXPECT_EQ(hardware_interface::lifecycle_state_names::ACTIVE, state.label());
 
-  ASSERT_EQ(hardware_interface::return_type::OK, sensor_hw.read());
+  ASSERT_EQ(hardware_interface::return_type::OK, sensor_hw.read(TIME, PERIOD));
 
   // Initiate recoverable error - call read 99 times OK and on 100-time will return error
   for (auto i = 2ul; i < TRIGGER_READ_WRITE_ERROR_CALLS; ++i)
   {
-    ASSERT_EQ(hardware_interface::return_type::OK, sensor_hw.read());
+    ASSERT_EQ(hardware_interface::return_type::OK, sensor_hw.read(TIME, PERIOD));
   }
-  ASSERT_EQ(hardware_interface::return_type::ERROR, sensor_hw.read());
+  ASSERT_EQ(hardware_interface::return_type::ERROR, sensor_hw.read(TIME, PERIOD));
 
   state = sensor_hw.get_state();
   EXPECT_EQ(lifecycle_msgs::msg::State::PRIMARY_STATE_UNCONFIGURED, state.id());
@@ -820,9 +852,9 @@ TEST(TestComponentInterfaces, dummy_sensor_read_error_behavior)
   // Initiate unrecoverable error - call read 99 times OK and on 100-time will return error
   for (auto i = 1ul; i < TRIGGER_READ_WRITE_ERROR_CALLS; ++i)
   {
-    ASSERT_EQ(hardware_interface::return_type::OK, sensor_hw.read());
+    ASSERT_EQ(hardware_interface::return_type::OK, sensor_hw.read(TIME, PERIOD));
   }
-  ASSERT_EQ(hardware_interface::return_type::ERROR, sensor_hw.read());
+  ASSERT_EQ(hardware_interface::return_type::ERROR, sensor_hw.read(TIME, PERIOD));
 
   state = sensor_hw.get_state();
   EXPECT_EQ(lifecycle_msgs::msg::State::PRIMARY_STATE_FINALIZED, state.id());
@@ -850,15 +882,15 @@ TEST(TestComponentInterfaces, dummy_system_read_error_behavior)
   EXPECT_EQ(lifecycle_msgs::msg::State::PRIMARY_STATE_ACTIVE, state.id());
   EXPECT_EQ(hardware_interface::lifecycle_state_names::ACTIVE, state.label());
 
-  ASSERT_EQ(hardware_interface::return_type::OK, system_hw.read());
-  ASSERT_EQ(hardware_interface::return_type::OK, system_hw.write());
+  ASSERT_EQ(hardware_interface::return_type::OK, system_hw.read(TIME, PERIOD));
+  ASSERT_EQ(hardware_interface::return_type::OK, system_hw.write(TIME, PERIOD));
 
   // Initiate error on write (this is first time therefore recoverable)
   for (auto i = 2ul; i < TRIGGER_READ_WRITE_ERROR_CALLS; ++i)
   {
-    ASSERT_EQ(hardware_interface::return_type::OK, system_hw.read());
+    ASSERT_EQ(hardware_interface::return_type::OK, system_hw.read(TIME, PERIOD));
   }
-  ASSERT_EQ(hardware_interface::return_type::ERROR, system_hw.read());
+  ASSERT_EQ(hardware_interface::return_type::ERROR, system_hw.read(TIME, PERIOD));
 
   state = system_hw.get_state();
   EXPECT_EQ(lifecycle_msgs::msg::State::PRIMARY_STATE_UNCONFIGURED, state.id());
@@ -878,15 +910,15 @@ TEST(TestComponentInterfaces, dummy_system_read_error_behavior)
   EXPECT_EQ(lifecycle_msgs::msg::State::PRIMARY_STATE_ACTIVE, state.id());
   EXPECT_EQ(hardware_interface::lifecycle_state_names::ACTIVE, state.label());
 
-  ASSERT_EQ(hardware_interface::return_type::OK, system_hw.read());
-  ASSERT_EQ(hardware_interface::return_type::OK, system_hw.write());
+  ASSERT_EQ(hardware_interface::return_type::OK, system_hw.read(TIME, PERIOD));
+  ASSERT_EQ(hardware_interface::return_type::OK, system_hw.write(TIME, PERIOD));
 
   // Initiate error on write (this is the second time therefore unrecoverable)
   for (auto i = 2ul; i < TRIGGER_READ_WRITE_ERROR_CALLS; ++i)
   {
-    ASSERT_EQ(hardware_interface::return_type::OK, system_hw.read());
+    ASSERT_EQ(hardware_interface::return_type::OK, system_hw.read(TIME, PERIOD));
   }
-  ASSERT_EQ(hardware_interface::return_type::ERROR, system_hw.read());
+  ASSERT_EQ(hardware_interface::return_type::ERROR, system_hw.read(TIME, PERIOD));
 
   state = system_hw.get_state();
   EXPECT_EQ(lifecycle_msgs::msg::State::PRIMARY_STATE_FINALIZED, state.id());
@@ -914,15 +946,15 @@ TEST(TestComponentInterfaces, dummy_system_write_error_behavior)
   EXPECT_EQ(lifecycle_msgs::msg::State::PRIMARY_STATE_ACTIVE, state.id());
   EXPECT_EQ(hardware_interface::lifecycle_state_names::ACTIVE, state.label());
 
-  ASSERT_EQ(hardware_interface::return_type::OK, system_hw.read());
-  ASSERT_EQ(hardware_interface::return_type::OK, system_hw.write());
+  ASSERT_EQ(hardware_interface::return_type::OK, system_hw.read(TIME, PERIOD));
+  ASSERT_EQ(hardware_interface::return_type::OK, system_hw.write(TIME, PERIOD));
 
   // Initiate error on write (this is first time therefore recoverable)
   for (auto i = 2ul; i < TRIGGER_READ_WRITE_ERROR_CALLS; ++i)
   {
-    ASSERT_EQ(hardware_interface::return_type::OK, system_hw.write());
+    ASSERT_EQ(hardware_interface::return_type::OK, system_hw.write(TIME, PERIOD));
   }
-  ASSERT_EQ(hardware_interface::return_type::ERROR, system_hw.write());
+  ASSERT_EQ(hardware_interface::return_type::ERROR, system_hw.write(TIME, PERIOD));
 
   state = system_hw.get_state();
   EXPECT_EQ(lifecycle_msgs::msg::State::PRIMARY_STATE_UNCONFIGURED, state.id());
@@ -942,15 +974,15 @@ TEST(TestComponentInterfaces, dummy_system_write_error_behavior)
   EXPECT_EQ(lifecycle_msgs::msg::State::PRIMARY_STATE_ACTIVE, state.id());
   EXPECT_EQ(hardware_interface::lifecycle_state_names::ACTIVE, state.label());
 
-  ASSERT_EQ(hardware_interface::return_type::OK, system_hw.read());
-  ASSERT_EQ(hardware_interface::return_type::OK, system_hw.write());
+  ASSERT_EQ(hardware_interface::return_type::OK, system_hw.read(TIME, PERIOD));
+  ASSERT_EQ(hardware_interface::return_type::OK, system_hw.write(TIME, PERIOD));
 
   // Initiate error on write (this is the second time therefore unrecoverable)
   for (auto i = 2ul; i < TRIGGER_READ_WRITE_ERROR_CALLS; ++i)
   {
-    ASSERT_EQ(hardware_interface::return_type::OK, system_hw.write());
+    ASSERT_EQ(hardware_interface::return_type::OK, system_hw.write(TIME, PERIOD));
   }
-  ASSERT_EQ(hardware_interface::return_type::ERROR, system_hw.write());
+  ASSERT_EQ(hardware_interface::return_type::ERROR, system_hw.write(TIME, PERIOD));
 
   state = system_hw.get_state();
   EXPECT_EQ(lifecycle_msgs::msg::State::PRIMARY_STATE_FINALIZED, state.id());
